@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2002 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,22 +24,20 @@
 #ifndef __GMIME_SESSION_H__
 #define __GMIME_SESSION_H__
 
+#include <glib.h>
+#include <glib-object.h>
+
 #ifdef __cplusplus
 extern "C" {
 #pragma }
 #endif /* __cplusplus */
 
-#include <glib.h>
-#include <glib-object.h>
-
-#include <gmime/gmime-type-utils.h>
-
 #define GMIME_TYPE_SESSION            (g_mime_session_get_type ())
-#define GMIME_SESSION(obj)            (GMIME_CHECK_CAST ((obj), GMIME_TYPE_SESSION, GMimeSession))
-#define GMIME_SESSION_CLASS(klass)    (GMIME_CHECK_CLASS_CAST ((klass), GMIME_TYPE_SESSION, GMimeSessionClass))
-#define GMIME_IS_SESSION(obj)         (GMIME_CHECK_TYPE ((obj), GMIME_TYPE_SESSION))
-#define GMIME_IS_SESSION_CLASS(klass) (GMIME_CHECK_CLASS_TYPE ((klass), GMIME_TYPE_SESSION))
-#define GMIME_SESSION_GET_CLASS(obj)  (GMIME_CHECK_GET_CLASS ((obj), GMIME_TYPE_SESSION, GMimeSessionClass))
+#define GMIME_SESSION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMIME_TYPE_SESSION, GMimeSession))
+#define GMIME_SESSION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMIME_TYPE_SESSION, GMimeSessionClass))
+#define GMIME_IS_SESSION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GMIME_TYPE_SESSION))
+#define GMIME_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GMIME_TYPE_SESSION))
+#define GMIME_SESSION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GMIME_TYPE_SESSION, GMimeSessionClass))
 
 typedef struct _GMimeSession GMimeSession;
 typedef struct _GMimeSessionClass GMimeSessionClass;
@@ -52,14 +50,14 @@ struct _GMimeSession {
 struct _GMimeSessionClass {
 	GObjectClass parent_class;
 	
-	gboolean (*is_online) (GMimeSession *session);
+	gboolean (* is_online) (GMimeSession *session);
 	
-	char *   (*request_passwd) (GMimeSession *session, const char *prompt,
-				    gboolean secret, const char *item,
-				    GError **err);
+	char *   (* request_passwd) (GMimeSession *session, const char *prompt,
+				     gboolean secret, const char *item,
+				     GError **err);
 	
-	void     (*forget_passwd)  (GMimeSession *session, const char *item,
-				    GError **err);
+	void     (* forget_passwd)  (GMimeSession *session, const char *item,
+				     GError **err);
 };
 
 
