@@ -31,13 +31,15 @@
 
 #include <gmime/gmime.h>
 
+#ifndef G_OS_WIN32
 #define ENABLE_ZENTIMER
 #include "zentimer.h"
+#endif
 
-#define TEST_PRESERVE_HEADERS
+/*#define TEST_PRESERVE_HEADERS
 #define TEST_GET_BODY
-#define PRINT_MIME_STRUCT
-/*#define TEST_WRITE_TO_STREAM*/
+#define PRINT_MIME_STRUCT*/
+#define TEST_WRITE_TO_STREAM
 
 void
 print_depth (int depth)
@@ -139,6 +141,7 @@ test_parser (GMimeStream *stream)
 	
 #ifdef TEST_WRITE_TO_STREAM
 	stream = g_mime_stream_fs_new (2);
+	g_mime_message_set_header (message, "Simple", "text");
 	g_mime_object_write_to_stream (GMIME_OBJECT (message), stream);
 	g_mime_stream_flush (stream);
 	GMIME_STREAM_FS (stream)->fd = -1;
